/*
*
* SPDX-License-Identifier: BSD-3-Clause
*
* Copyright (c) 2016-2022, Arm Limited. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
* - Redistributions of source code must retain the above copyright notice, this
*   list of conditions and the following disclaimer.
* - Redistributions in binary form must reproduce the above copyright notice, this
*    list of conditions and the following disclaimer in the documentation and/or
*    other materials provided with the distribution.
* - Neither the name of ARM nor the names of its contributors may be used to
*    endorse or promote products derived from this software without specific prior
*    written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
* DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
* ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
* ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

#if !defined(__ISP_SENSOR_H__)
#define __ISP_SENSOR_H__


/*-----------------------------------------------------------------------------
Initialization sequence - do not edit
-----------------------------------------------------------------------------*/

#include "sensor_init.h"

static acam_reg_t settings[] = {
    { 0x10, 0x0, 0x1,1 },
    { 0x14, 0x20, 0x0,2 },
    { 0x18, 0x200020, 0x0,4 },
    { 0x20, 0x3, 0x103,2 },
    { 0x30, 0xffffffff, 0x0,4 },
    { 0x34, 0xffffffff, 0x0,4 },
    { 0x40, 0x0, 0x1,1 },
    { 0x5c, 0x0, 0x3f,1 },
    { 0x64, 0x0, 0x20,1 },
    { 0x70, 0x1, 0x101,2 },
    { 0x88, 0x0, 0xffff0000,4 },
    { 0x8c, 0x0, 0x0,2 },
    { 0x94, 0x0, 0x0,4 },
    { 0x9c, 0x1, 0x87,1 },
    //stop sequence - address is 0x0000
    { 0x0000, 0x0000, 0x0000, 0x0000 }
};


static acam_reg_t settings_context[] = {
    { 0x18e88, 0x4380780, 0x0,4 },
    { 0x18e8c, 0x0, 0x3030000,4 },
    { 0x18eac, 0x30, 0x3f,1 },
    { 0x18eb0, 0x2, 0xf,1 },
    { 0x18eb8, 0x0, 0x3,1 },
    { 0x18ebc, 0x0, 0x7b,1 },
    { 0x18ec0, 0x0, 0x3a,1 },
    { 0x18ec4, 0x2, 0x1f,1 },
    { 0x18ec8, 0x2, 0x1f,1 },
    { 0x18ecc, 0x0, 0x303,2 },
    { 0x18ed0, 0x1000000, 0x1017337,4 },
    { 0x18ed4, 0x30300, 0x30303,4 },
    { 0x18ed8, 0x0, 0x3,1 },
    { 0x18edc, 0x3, 0x0,1 },
    { 0x18ee0, 0xfffff, 0xfffff,4 },
    { 0x18ee4, 0xfffff, 0xfffff,4 },
    { 0x18ee8, 0xfffff, 0xfffff,4 },
    { 0x18eec, 0x8ffff, 0xfffff,4 },
    { 0x18ef0, 0x8ffff, 0xfffff,4 },
    { 0x18ef4, 0x8ffff, 0xfffff,4 },
    { 0x18ef8, 0x0, 0x0,2 },
    { 0x18efc, 0xfffff, 0xfffff,4 },
    { 0x18f00, 0x1000001, 0x3fff3fff,4 },
    { 0x18f04, 0x1000001, 0x3fff3fff,4 },
    { 0x18f08, 0x0, 0x3,1 },
    { 0x18f0c, 0x3, 0x0,1 },
    { 0x18f10, 0xfffff, 0xfffff,4 },
    { 0x18f14, 0xfffff, 0xfffff,4 },
    { 0x18f18, 0xfffff, 0xfffff,4 },
    { 0x18f1c, 0x8ffff, 0xfffff,4 },
    { 0x18f20, 0x8ffff, 0xfffff,4 },
    { 0x18f24, 0x8ffff, 0xfffff,4 },
    { 0x18f28, 0x0, 0x0,2 },
    { 0x18f2c, 0xfffff, 0xfffff,4 },
    { 0x18f30, 0x1000001, 0x3fff3fff,4 },
    { 0x18f34, 0x1000001, 0x3fff3fff,4 },
    { 0x18f98, 0x20000, 0x70007,4 },
    { 0x18f9c, 0x0, 0x3ffff,4 },
    { 0x18fa0, 0x0, 0x1fff,2 },
    { 0x18fa4, 0x0, 0xfff,2 },
    { 0x18fa8, 0x0, 0x0,4 },
    { 0x18fac, 0x0, 0x0,2 },
    { 0x18fb0, 0x0, 0xf0f0f0f,4 },
    { 0x18fc4, 0x0, 0xfff0fff,4 },
    { 0x18fc8, 0x0, 0xfff0fff,4 },
    { 0x18fcc, 0x0, 0xfff0fff,4 },
    { 0x18fd0, 0x0, 0xfff0fff,4 },
    { 0x18fd8, 0x1000100, 0x1fff1fff,4 },
    { 0x18fe0, 0x0, 0xfff0fff,4 },
    { 0x18fe8, 0x100, 0xfff,2 },
    { 0x18ff0, 0xc000f00, 0xfff0fff,4 },
    { 0x18ffc, 0xf000f0, 0xfff0fff,4 },
    { 0x19004, 0xc800, 0xfffff,4 },
    { 0x19008, 0x180, 0xfff,2 },
    { 0x1900c, 0xc000000, 0xfff0000,4 },
    { 0x19014, 0x1000100, 0xfff0fff,4 },
    { 0x19020, 0x0, 0x3f3f3f,4 },
    { 0x19024, 0x0, 0xfff0fff,4 },
    { 0x19048, 0x200000, 0xff0fff,4 },
    { 0x1904c, 0x0, 0x107,2 },
    { 0x19050, 0x0, 0xfff0fff,4 },
    { 0x19058, 0x0, 0xfff,2 },
    { 0x1905c, 0x0, 0xfff0000,4 },
    { 0x19060, 0x0, 0xfff0fff,4 },
    { 0x19264, 0x1, 0x11,1 },
    { 0x19268, 0x1, 0x11,1 },
    { 0x1926c, 0x13b, 0x1fff,2 },
    { 0x19270, 0xc800, 0xfffff,4 },
    { 0x19274, 0x0, 0xfffff,4 },
    { 0x19278, 0x0, 0xfffff,4 },
    { 0x1927c, 0x0, 0xfffff,4 },
    { 0x19280, 0x0, 0xfffff,4 },
    { 0x19284, 0xc800, 0xfffff,4 },
    { 0x19288, 0x596702f4, 0xffff8fff,4 },
    { 0x1928c, 0x4, 0xcc,1 },
    { 0x19294, 0x500255, 0xfff0fff,4 },
    { 0x19298, 0x800, 0xff0fff,4 },
    { 0x192a4, 0x0, 0xfff0fff,4 },
    { 0x19348, 0x5c, 0x0,1 },
    { 0x1934c, 0x0, 0xf,1 },
    { 0x19350, 0x21c03c0, 0x0,4 },
    { 0x19354, 0x6ea, 0x0,2 },
    { 0x19358, 0x77637763, 0x0,4 },
    { 0x1935c, 0xffe5, 0x0,2 },
    { 0x19360, 0x0, 0xff01,2 },
    { 0x19364, 0x4000000, 0xfff0fff,4 },
    { 0x19368, 0xc000800, 0xfff0fff,4 },
    { 0x1936c, 0x0, 0xff00ff,4 },
    { 0x19370, 0xe, 0xf,1 },
    { 0x19374, 0x0, 0x0,4 },
    { 0x19378, 0x1c1400, 0x0,4 },
    { 0x1aa1c, 0x1, 0x31f,2 },
    { 0x1aa20, 0x0, 0x3f,1 },
    { 0x1aa24, 0x3200fa, 0xfff03ff,4 },
    { 0x1aa28, 0x3b00, 0xfffff07,4 },
    { 0x1aa2c, 0x0, 0xfff0fff,4 },
    { 0x1aa30, 0x0, 0xfff,2 },
    { 0x1aa34, 0x40, 0x0,4 },
    { 0x1aa38, 0x3, 0x3f0703,4 },
    { 0x1aa3c, 0x353a3d, 0x3f3f3f,4 },
    { 0x1ab78, 0x0, 0x3,1 },
    { 0x1ab7c, 0x14, 0x0,1 },
    { 0x1ab84, 0x0, 0x0,4 },
    { 0x1ab8c, 0x0, 0x0,4 },
    { 0x1ab94, 0x12c0, 0x0,4 },
    { 0x1ab98, 0x2, 0x2,1 },
    { 0x1ab9c, 0x0, 0x0,4 },
    { 0x1aba0, 0x40, 0x0,4 },
    { 0x1aba4, 0x0, 0x0,4 },
    { 0x1aba8, 0xf007e00, 0x1fff7f0f,4 },
    { 0x1abac, 0xf007e00, 0x1fff7e0f,4 },
    { 0x1abc0, 0x2f4, 0xfff,2 },
    { 0x1abc4, 0xc800, 0xfffff,4 },
    { 0x1abc8, 0x16e84, 0x1ffff,4 },
    { 0x1abcc, 0xc800, 0xfffff,4 },
    { 0x1abd0, 0xc800, 0xfffff,4 },
    { 0x1abd4, 0xc800, 0xfffff,4 },
    { 0x1abd8, 0xc800, 0xfffff,4 },
    { 0x1abfc, 0x1f1fe405, 0x3f3fff1f,4 },
    { 0x1ac00, 0x0, 0x1,1 },
    { 0x1ac04, 0x0, 0xfff,2 },
    { 0x1ac08, 0xe3e3e3, 0x0,4 },
    { 0x1ac0c, 0x1000, 0x0,2 },
    { 0x1ac10, 0x1000100, 0xfff0fff,4 },
    { 0x1ac14, 0x1000100, 0xfff0fff,4 },
    { 0x1ac18, 0x1000100, 0xfff0fff,4 },
    { 0x1ac1c, 0x1000100, 0xfff0fff,4 },
    { 0x1ac20, 0x100, 0xfff,2 },
    { 0x1ac24, 0x0, 0xfffff,4 },
    { 0x1ac28, 0x4229, 0xc369,2 },
    { 0x1ac2c, 0x50, 0x0,1 },
    { 0x1ac30, 0x0, 0xfffff,4 },
    { 0x1ac34, 0xd9999, 0xfffff,4 },
    { 0x1ac38, 0x100, 0xfff,2 },
    { 0x1ac3c, 0x202, 0x3ff0303,4 },
    { 0x1ac40, 0x200, 0x3ff,2 },
    { 0x1ac44, 0xffff0000, 0x0,4 },
    { 0x1ac48, 0xffff0000, 0x0,4 },
    { 0x1ac4c, 0xb4dc0a00, 0xffff0f00,4 },
    { 0x1ac50, 0x44c, 0x0,2 },
    { 0x1ac5c, 0x0, 0x7,1 },
    { 0x1ac60, 0x0, 0xfffff,4 },
    { 0x1ac64, 0x1000100, 0xfff0fff,4 },
    { 0x1ac68, 0x1000100, 0xfff0fff,4 },
    { 0x1ac6c, 0x0, 0x1,1 },
    { 0x1ae7c, 0xaa, 0x0,1 },
    { 0x1ae88, 0xf0, 0xfff,2 },
    { 0x1aea0, 0x0, 0x0,1 },
    { 0x1aea8, 0x5596, 0x0,2 },
    { 0x1aeb0, 0x8191e14, 0x0,4 },
    { 0x1aeb4, 0x1f8b, 0x1fff,2 },
    { 0x1aeb8, 0x1fa4, 0x1fff,2 },
    { 0x1aec0, 0xb2, 0x0,1 },
    { 0x1aec4, 0xf0, 0xfff,2 },
    { 0x1aecc, 0x3330333, 0x1fff1fff,4 },
    { 0x1aed0, 0x8, 0xff0fff,4 },
    { 0x1aed4, 0x4000, 0xfffff,4 },
    { 0x1aed8, 0xfa00000, 0xfff0000,4 },
    { 0x1aedc, 0x4000, 0xfffff,4 },
    { 0x1aee0, 0x4e, 0xff0fff,4 },
    { 0x1aee4, 0x4000, 0xfffff,4 },
    { 0x1aee8, 0xfa0, 0xfff,2 },
    { 0x1aeec, 0x4000, 0xfffff,4 },
    { 0x1afc8, 0x1, 0x1,1 },
    { 0x1afcc, 0x300, 0xfff,2 },
    { 0x1afd0, 0x40000c8, 0xfff0fff,4 },
    { 0x1afd4, 0x200fff, 0xff0fff,4 },
    { 0x1afd8, 0x6ea, 0x0,2 },
    { 0x1afdc, 0x21c03c0, 0x0,4 },
    { 0x1afe0, 0x1cd, 0x1fff,2 },
    { 0x1afe4, 0x10c4, 0x1fff,2 },
    { 0x1afe8, 0x1009, 0x1fff,2 },
    { 0x1afec, 0x105d, 0x1fff,2 },
    { 0x1aff0, 0x194, 0x1fff,2 },
    { 0x1aff4, 0x1037, 0x1fff,2 },
    { 0x1aff8, 0xe, 0x1fff,2 },
    { 0x1affc, 0x10d5, 0x1fff,2 },
    { 0x1b000, 0x1c7, 0x1fff,2 },
    { 0x1b004, 0x40, 0xfff0fff,4 },
    { 0x1b008, 0x200, 0xfff,2 },
    { 0x1b00c, 0xf8, 0xfff0fff,4 },
    { 0x1b010, 0x7ad, 0xfff,2 },
    { 0x1b014, 0x320, 0xfff0fff,4 },
    { 0x1b018, 0x960, 0xfff,2 },
    { 0x1b01c, 0x100, 0xfff0fff,4 },
    { 0x1b020, 0x2d0, 0xfff,2 },
    { 0x1b024, 0xfff01f4, 0xfff0fff,4 },
    { 0x1b028, 0xc83, 0xfff,2 },
    { 0x1b02c, 0x6e, 0xfff0fff,4 },
    { 0x1b030, 0xcd, 0xfff,2 },
    { 0x1b034, 0x46, 0xfff0fff,4 },
    { 0x1b038, 0x5dc, 0xfff,2 },
    { 0x1b03c, 0x190, 0xfff0fff,4 },
    { 0x1b040, 0xd48, 0xfff,2 },
    { 0x1b044, 0x5dc, 0xfff0fff,4 },
    { 0x1b048, 0xfff, 0xfff,2 },
    { 0x1b04c, 0x20, 0xfff0fff,4 },
    { 0x1b050, 0x0, 0xfff,2 },
    { 0x1b054, 0x0, 0x0,1 },
    { 0x1b07c, 0x1, 0x1,1 },
    { 0x1b080, 0x1ae, 0x1fff,2 },
    { 0x1b084, 0x10aa, 0x1fff,2 },
    { 0x1b088, 0x1009, 0x1fff,2 },
    { 0x1b090, 0x1051, 0x1fff,2 },
    { 0x1b094, 0x180, 0x1fff,2 },
    { 0x1b098, 0x1034, 0x1fff,2 },
    { 0x1b0a0, 0x12, 0x1fff,2 },
    { 0x1b0a4, 0x10ba, 0x1fff,2 },
    { 0x1b0a8, 0x1a3, 0x1fff,2 },
    { 0x1b0b0, 0x100, 0xfff,2 },
    { 0x1b0b4, 0x100, 0xfff,2 },
    { 0x1b0b8, 0x100, 0xfff,2 },
    { 0x1b0c0, 0x0, 0xfff,2 },
    { 0x1b0c4, 0x0, 0xfff,2 },
    { 0x1b0c8, 0x0, 0xfff,2 },
    { 0x1b0d0, 0x1, 0x1,1 },
    { 0x1b0d4, 0x1, 0x1,1 },
    { 0x1b0d8, 0x0, 0x0,2 },
    { 0x1b0e0, 0x96, 0xfff,2 },
    { 0x1b0e4, 0x333, 0xfff,2 },
    { 0x1b0e8, 0x258, 0xfff,2 },
    { 0x1b0ec, 0xfbd8, 0x0,2 },
    { 0x1b0f0, 0x3e, 0xfff,2 },
    { 0x1b0f4, 0xe7b4, 0x0,2 },
    { 0x1b0f8, 0x3ff, 0xfff,2 },
    { 0x1b0fc, 0xffff, 0x0,2 },
    { 0x1b100, 0xb9, 0xfff,2 },
    { 0x1b104, 0x1f4, 0x0,2 },
    { 0x1b274, 0x0, 0x0,4 },
    { 0x1b278, 0x10, 0xfff,2 },
    { 0x1b27c, 0x20, 0xfff,2 },
    { 0x1b280, 0xd0, 0xfff,2 },
    { 0x1b284, 0xe0, 0xfff,2 },
    { 0x1b298, 0xf0f, 0x0,2 },
    { 0x1b29c, 0x0, 0x1,1 },
    { 0x1b2a0, 0x3ff, 0x3ff,2 },
    { 0x1b2a4, 0x0, 0x3ff,2 },
    { 0x1b2a8, 0x1ff, 0xfff,2 },
    { 0x1b2ac, 0x40, 0xfff,2 },
    { 0x1b2b0, 0x1ff, 0xfff,2 },
    { 0x1b2b4, 0x40, 0xfff,2 },
    { 0x1b2c4, 0xf0f, 0x0,2 },
    { 0x1b2c8, 0xfff, 0xfff,2 },
    { 0x1b2cc, 0x0, 0xfff,2 },
    { 0x1b2d0, 0xfff, 0xfff,2 },
    { 0x1b2d4, 0x0, 0xfff,2 },
    { 0x1b708, 0x77f0000, 0x0,4 },
    { 0x1b70c, 0x4370000, 0x0,4 },
    { 0x1b710, 0xf0f, 0x0,2 },
    { 0x1b714, 0xf, 0xf,1 },
    { 0x1b718, 0xf000, 0xfffff,4 },
    { 0x1b71c, 0x185, 0x1ff,2 },
    { 0x1b720, 0xc003c003, 0x0,4 },
    { 0x1b724, 0x3, 0x7,1 },
    { 0x1b728, 0x1fa6, 0x3fff,2 },
    { 0x1b72c, 0x1faa, 0x3fff,2 },
    { 0x1b730, 0x1, 0x0,1 },
    { 0x1b734, 0x0, 0x0,1 },
    { 0x1b740, 0x0, 0x7,1 },
    { 0x1b764, 0xf0f, 0x0,2 },
    { 0x1bbac, 0x1, 0x0,1 },
    { 0x1bbb0, 0x0, 0x0,1 },
    { 0x1bbbc, 0x0, 0x7,1 },
    { 0x1bbe0, 0xf0f, 0x0,2 },
    { 0x1c028, 0x0, 0x1,1 },
    { 0x1c02c, 0x0, 0x0,2 },
    { 0x1c030, 0x0, 0x0,2 },
    { 0x1c034, 0xffff, 0x0,2 },
    { 0x1c038, 0xffff, 0x0,2 },
    { 0x1c040, 0x29000010, 0xffff0010,4 },
    { 0x1c044, 0x780, 0x0,2 },
    { 0x1c048, 0x438, 0x0,2 },
    { 0x1c04c, 0x500, 0x0,2 },
    { 0x1c050, 0x2d0, 0x0,2 },
    { 0x1c054, 0x180000, 0xffffff,4 },
    { 0x1c058, 0x0, 0xf,1 },
    { 0x1c05c, 0x180000, 0xffffff,4 },
    { 0x1c060, 0x0, 0xf,1 },
    { 0x1c064, 0x1, 0x1,1 },
    { 0x1c068, 0x1000100, 0xfff0fff,4 },
    { 0x1c06c, 0x100, 0xfff,2 },
    { 0x1c070, 0x0, 0xfff0fff,4 },
    { 0x1c074, 0x0, 0xfff,2 },
    { 0x1c078, 0x1, 0x1,1 },
    { 0x1c07c, 0xa, 0x1ff,2 },
    { 0x1c080, 0x131e4c, 0xffffff,4 },
    { 0x1c084, 0x0, 0xff03ff,4 },
    { 0x1c088, 0x33203fc, 0x3ffffff,4 },
    { 0x1c08c, 0x6a40000, 0xffff00ff,4 },
    { 0x1c090, 0xcd3fff, 0x3fff3fff,4 },
    { 0x1c094, 0x0, 0xf,1 },
    { 0x1c098, 0x1, 0xf,1 },
    { 0x1c09c, 0xff, 0x0,2 },
    { 0x1c0a0, 0x8001, 0x0,2 },
    { 0x1c0a4, 0x0, 0x0,2 },
    { 0x1c0a8, 0x8001, 0x0,2 },
    { 0x1c0ac, 0xff, 0x0,2 },
    { 0x1c0b0, 0x0, 0x0,2 },
    { 0x1c0b4, 0x8001, 0x0,2 },
    { 0x1c0b8, 0x8001, 0x0,2 },
    { 0x1c0bc, 0x100, 0x0,2 },
    { 0x1c0c0, 0x0, 0x7ff,2 },
    { 0x1c0c4, 0x0, 0x7ff,2 },
    { 0x1c0c8, 0x0, 0x7ff,2 },
    { 0x1c0cc, 0x0, 0x3ff,2 },
    { 0x1c0d0, 0x3ff, 0x3ff,2 },
    { 0x1c0d4, 0x0, 0x3ff,2 },
    { 0x1c0d8, 0x3ff, 0x3ff,2 },
    { 0x1c0dc, 0x3ff, 0x3ff,2 },
    { 0x1c0e0, 0x3ff, 0x3ff,2 },
    { 0x1c0e4, 0x3ff, 0x3ff,2 },
    { 0x1c0e8, 0x0, 0x17,1 },
    { 0x1c0ec, 0x2, 0xbdf,2 },
    { 0x1c0f0, 0x4380780, 0x0,4 },
    { 0x1c0f4, 0x0, 0x0,4 },
    { 0x1c0f8, 0x0, 0x0,4 },
    { 0x1c0fc, 0x0, 0x0,4 },
    { 0x1c100, 0x0, 0x0,4 },
    { 0x1c104, 0x0, 0x0,4 },
    { 0x1c108, 0x0, 0xf,1 },
    { 0x1c10c, 0x1e00, 0x0,4 },
    { 0x1c12c, 0x0, 0x0,2 },
    { 0x1c130, 0x0, 0x0,2 },
    { 0x1c134, 0x0, 0x0,2 },
    { 0x1c138, 0x0, 0xffff0001,4 },
    { 0x1c13c, 0xf000f0c, 0xfff0f0f,4 },
    { 0x1c140, 0x0, 0xf,1 },
    { 0x1c144, 0x0, 0xbdf,2 },
    { 0x1c148, 0x4380780, 0x0,4 },
    { 0x1c14c, 0x0, 0x0,4 },
    { 0x1c150, 0x0, 0x0,4 },
    { 0x1c154, 0x0, 0x0,4 },
    { 0x1c158, 0x0, 0x0,4 },
    { 0x1c15c, 0x0, 0x0,4 },
    { 0x1c160, 0x0, 0xf,1 },
    { 0x1c164, 0x1000, 0x0,4 },
    { 0x1c184, 0x0, 0x0,2 },
    { 0x1c188, 0x0, 0x0,2 },
    { 0x1c18c, 0x0, 0x0,2 },
    { 0x1c190, 0x0, 0xffff0001,4 },
    { 0x1c194, 0xf000f0c, 0xfff0f0f,4 },
    { 0x1c198, 0x0, 0xf,1 },
    { 0x1c19c, 0x0, 0x1,1 },
    { 0x1c1a0, 0x0, 0x0,2 },
    { 0x1c1a4, 0x0, 0x0,2 },
    { 0x1c1a8, 0xffff, 0x0,2 },
    { 0x1c1ac, 0xffff, 0x0,2 },
    { 0x1c1b4, 0x29000010, 0xffff0010,4 },
    { 0x1c1b8, 0x780, 0x0,2 },
    { 0x1c1bc, 0x438, 0x0,2 },
    { 0x1c1c0, 0x500, 0x0,2 },
    { 0x1c1c4, 0x2d0, 0x0,2 },
    { 0x1c1c8, 0x180000, 0xffffff,4 },
    { 0x1c1cc, 0x0, 0xf,1 },
    { 0x1c1d0, 0x180000, 0xffffff,4 },
    { 0x1c1d4, 0x0, 0xf,1 },
    { 0x1c1d8, 0x1, 0x1,1 },
    { 0x1c1dc, 0x1000100, 0xfff0fff,4 },
    { 0x1c1e0, 0x100, 0xfff,2 },
    { 0x1c1e4, 0x0, 0xfff0fff,4 },
    { 0x1c1e8, 0x0, 0xfff,2 },
    { 0x1c1ec, 0x0, 0x1,1 },
    { 0x1c1f0, 0x46, 0x1ff,2 },
    { 0x1c1f4, 0x131e4c, 0xffffff,4 },
    { 0x1c1f8, 0x0, 0xff03ff,4 },
    { 0x1c1fc, 0x33203fc, 0x3ffffff,4 },
    { 0x1c200, 0x6a40000, 0xffff00ff,4 },
    { 0x1c204, 0xcd3fff, 0x3fff3fff,4 },
    { 0x1c208, 0x0, 0xf,1 },
    { 0x1c20c, 0x1, 0xf,1 },
    { 0x1c210, 0xff, 0x0,2 },
    { 0x1c214, 0x8001, 0x0,2 },
    { 0x1c218, 0x0, 0x0,2 },
    { 0x1c21c, 0x8001, 0x0,2 },
    { 0x1c220, 0xff, 0x0,2 },
    { 0x1c224, 0x0, 0x0,2 },
    { 0x1c228, 0x8001, 0x0,2 },
    { 0x1c22c, 0x8001, 0x0,2 },
    { 0x1c230, 0x100, 0x0,2 },
    { 0x1c234, 0x0, 0x7ff,2 },
    { 0x1c238, 0x0, 0x7ff,2 },
    { 0x1c23c, 0x0, 0x7ff,2 },
    { 0x1c240, 0x0, 0x3ff,2 },
    { 0x1c244, 0x3ff, 0x3ff,2 },
    { 0x1c248, 0x0, 0x3ff,2 },
    { 0x1c24c, 0x3ff, 0x3ff,2 },
    { 0x1c250, 0x3ff, 0x3ff,2 },
    { 0x1c254, 0x3ff, 0x3ff,2 },
    { 0x1c258, 0x3ff, 0x3ff,2 },
    { 0x1c25c, 0x0, 0x17,1 },
    { 0x1c260, 0x2, 0xbdf,2 },
    { 0x1c264, 0x4380780, 0x0,4 },
    { 0x1c268, 0x0, 0x0,4 },
    { 0x1c26c, 0x0, 0x0,4 },
    { 0x1c270, 0x0, 0x0,4 },
    { 0x1c274, 0x0, 0x0,4 },
    { 0x1c278, 0x0, 0x0,4 },
    { 0x1c27c, 0x0, 0xf,1 },
    { 0x1c280, 0x1e00, 0x0,4 },
    { 0x1c2a0, 0x0, 0x0,2 },
    { 0x1c2a4, 0x0, 0x0,2 },
    { 0x1c2a8, 0x0, 0x0,2 },
    { 0x1c2ac, 0x0, 0xffff0001,4 },
    { 0x1c2b0, 0xf000f0c, 0xfff0f0f,4 },
    { 0x1c2b4, 0x0, 0xf,1 },
    { 0x1c2b8, 0x0, 0xbdf,2 },
    { 0x1c2bc, 0x4380780, 0x0,4 },
    { 0x1c2c0, 0x0, 0x0,4 },
    { 0x1c2c4, 0x0, 0x0,4 },
    { 0x1c2c8, 0x0, 0x0,4 },
    { 0x1c2cc, 0x0, 0x0,4 },
    { 0x1c2d0, 0x0, 0x0,4 },
    { 0x1c2d4, 0x0, 0xf,1 },
    { 0x1c2d8, 0x1000, 0x0,4 },
    { 0x1c2f8, 0x0, 0x0,2 },
    { 0x1c2fc, 0x0, 0x0,2 },
    { 0x1c300, 0x0, 0x0,2 },
    { 0x1c304, 0x0, 0xffff0001,4 },
    { 0x1c308, 0xf000f0c, 0xfff0f0f,4 },
    { 0x1c30c, 0x0, 0xf,1 },
    { 0x1c310, 0x0, 0x1,1 },
    //stop sequence - address is 0x0000
    { 0x0000, 0x0000, 0x0000, 0x0000 }
};


static acam_reg_t settings_fpga[] = {
    { 0x220040, 0x0, 0x0,4 },
    { 0x220044, 0x0, 0x0,4 },
    { 0x220048, 0x0, 0x0,4 },
    { 0x22004c, 0x0, 0x0,2 },
    { 0x22010c, 0x0, 0xc0070000,4 },
    { 0x220114, 0x0, 0x0,4 },
    { 0x220124, 0x0, 0x0,4 },
    { 0x220134, 0x0, 0x0,4 },
    { 0x220144, 0x0, 0x0,4 },
    { 0x220150, 0x0, 0x3,1 },
    { 0x220154, 0x2, 0x3,1 },
    { 0x220158, 0x0, 0x3f3f,2 },
    { 0x2201f0, 0xf, 0xf0f0f0f,4 },
    { 0x2201f4, 0x7, 0x7,1 },
    { 0x2201fc, 0x0, 0xf000000,4 },
    { 0x22020c, 0x0, 0xc0070000,4 },
    { 0x220214, 0x0, 0x0,4 },
    { 0x220224, 0x0, 0x0,4 },
    { 0x220234, 0x0, 0x0,4 },
    { 0x220244, 0x0, 0x0,4 },
    { 0x220250, 0x0, 0x3,1 },
    { 0x220254, 0x2, 0x3,1 },
    { 0x220258, 0x0, 0x3f3f,2 },
    { 0x2202f0, 0xf, 0xf0f0f0f,4 },
    { 0x2202f4, 0x7, 0x7,1 },
    { 0x2202fc, 0x0, 0xf000000,4 },
    { 0x220300, 0x0, 0x3,1 },
    { 0x220304, 0x4e20, 0x3ffffff,4 },
    { 0x220308, 0x118, 0x3ffffff,4 },
    { 0x22030c, 0x135b0, 0x3ffffff,4 },
    { 0x220310, 0x780, 0x1fff,2 },
    { 0x220314, 0x438, 0x1fff,2 },
    { 0x220380, 0x6, 0x0,1 },
    { 0x220390, 0x0, 0x0,4 },
    { 0x220394, 0x1f80, 0x0,4 },
    { 0x220398, 0x0, 0x1,1 },
    { 0x2203a0, 0x0, 0x0,4 },
    { 0x220540, 0x0, 0x1,1 },
    { 0x22054c, 0x4380780, 0x0,4 },
    { 0x220550, 0x0, 0x7,1 },
    { 0x220554, 0x0, 0x0,4 },
    { 0x220560, 0x0, 0x0,4 },
    { 0x220564, 0x0, 0x0,4 },
    { 0x220568, 0x0, 0x0,4 },
    { 0x22056c, 0x1000, 0x0,4 },
    { 0x220570, 0x0, 0x73,1 },
    { 0x220580, 0x0, 0x1,1 },
    { 0x22058c, 0x4380780, 0x0,4 },
    { 0x220590, 0x0, 0x7,1 },
    { 0x220594, 0x0, 0x0,4 },
    { 0x2205a0, 0x0, 0x0,4 },
    { 0x2205a4, 0x0, 0x0,4 },
    { 0x2205a8, 0x0, 0x0,4 },
    { 0x2205ac, 0x1000, 0x0,4 },
    { 0x2205b0, 0x0, 0x73,1 },
    { 0x2205c0, 0x0, 0x1,1 },
    { 0x2205cc, 0x4380780, 0x0,4 },
    { 0x2205d0, 0x0, 0x7,1 },
    { 0x2205d4, 0x0, 0x0,4 },
    { 0x2205e0, 0x0, 0x0,4 },
    { 0x2205e4, 0x0, 0x0,4 },
    { 0x2205e8, 0x0, 0x0,4 },
    { 0x2205ec, 0x1000, 0x0,4 },
    { 0x2205f0, 0x0, 0x73,1 },
    { 0x220600, 0x6, 0x19fdf0f,4 },
    { 0x220604, 0x1000700, 0xf0f1f03,4 },
    { 0x220608, 0xffff, 0x0,2 },
    { 0x22060c, 0x0, 0x0,2 },
    { 0x220610, 0x780, 0x0,2 },
    { 0x220614, 0x0, 0x0,2 },
    { 0x220618, 0x780, 0x0,2 },
    { 0x22061c, 0xffff, 0x0,2 },
    { 0x220620, 0x0, 0x0,2 },
    { 0x220624, 0x438, 0x0,2 },
    { 0x220630, 0x1, 0x87,1 },
    { 0x220634, 0x0, 0x30000,4 },
    { 0x220680, 0x0, 0x1,1 },
    { 0x220684, 0x0, 0x1,1 },
    { 0x220700, 0x0, 0x7,1 },
    { 0x220704, 0x2, 0x0,1 },
    { 0x220708, 0xffff, 0x0,2 },
    { 0x22070c, 0xffff, 0x0,2 },
    { 0x220710, 0xffff, 0x0,2 },
    { 0x220714, 0x8fff, 0x0,2 },
    { 0x220718, 0x8fff, 0x0,2 },
    { 0x22071c, 0x8fff, 0x0,2 },
    { 0x220720, 0x3caa, 0x0,2 },
    { 0x220724, 0x0, 0x0,2 },
    { 0x220728, 0x1, 0x3fff,2 },
    { 0x22072c, 0x100, 0x3fff,2 },
    { 0x220730, 0x1, 0x3fff,2 },
    { 0x220738, 0x100, 0x3fff,2 },
    { 0x220780, 0x6, 0xcf,1 },
    { 0x220784, 0x0, 0xf,1 },
    { 0x220788, 0x780, 0x0,2 },
    { 0x22078c, 0x438, 0x0,2 },
    { 0x220790, 0x0, 0x0,4 },
    { 0x220794, 0x0, 0x0,4 },
    { 0x220798, 0x0, 0x0,4 },
    { 0x22079c, 0x0, 0x0,4 },
    { 0x2207a0, 0x0, 0x0,4 },
    { 0x2207a4, 0x0, 0xf,1 },
    { 0x2207a8, 0xf00, 0x0,4 },
    { 0x2207ac, 0x0, 0x3,1 },
    { 0x2207c8, 0x0, 0xf,1 },
    { 0x2207cc, 0x0, 0x0,1 },
    { 0x2207d0, 0x0, 0x0,1 },
    { 0x2207d4, 0x0, 0x0,1 },
    { 0x2207e0, 0x0, 0x0,4 },
    { 0x220800, 0x6, 0x19fdf0f,4 },
    { 0x220804, 0x1000700, 0xf0f1f03,4 },
    { 0x220808, 0xffff, 0x0,2 },
    { 0x22080c, 0x0, 0x0,2 },
    { 0x220810, 0x780, 0x0,2 },
    { 0x220814, 0x0, 0x0,2 },
    { 0x220818, 0x0, 0x0,2 },
    { 0x22081c, 0xffff, 0x0,2 },
    { 0x220820, 0x0, 0x0,2 },
    { 0x220824, 0x438, 0x0,2 },
    { 0x220830, 0x1, 0x87,1 },
    { 0x220834, 0x0, 0x30000,4 },
    { 0x220880, 0x0, 0x1,1 },
    { 0x220884, 0x0, 0x1,1 },
    { 0x220900, 0x0, 0x7,1 },
    { 0x220904, 0x5, 0x0,1 },
    { 0x220908, 0xffff, 0x0,2 },
    { 0x22090c, 0xffff, 0x0,2 },
    { 0x220910, 0xffff, 0x0,2 },
    { 0x220914, 0x8fff, 0x0,2 },
    { 0x220918, 0x8fff, 0x0,2 },
    { 0x22091c, 0x8fff, 0x0,2 },
    { 0x220920, 0x3caa, 0x0,2 },
    { 0x220924, 0x0, 0x0,2 },
    { 0x220928, 0x1, 0x3fff,2 },
    { 0x22092c, 0x100, 0x3fff,2 },
    { 0x220930, 0x1, 0x3fff,2 },
    { 0x220938, 0x100, 0x3fff,2 },
    { 0x220980, 0x6, 0xcf,1 },
    { 0x220984, 0x0, 0xf,1 },
    { 0x220988, 0x780, 0x0,2 },
    { 0x22098c, 0x438, 0x0,2 },
    { 0x220990, 0x0, 0x0,4 },
    { 0x220994, 0x0, 0x0,4 },
    { 0x220998, 0x0, 0x0,4 },
    { 0x22099c, 0x0, 0x0,4 },
    { 0x2209a0, 0x0, 0x0,4 },
    { 0x2209a4, 0x0, 0xf,1 },
    { 0x2209a8, 0xf00, 0x0,4 },
    { 0x2209ac, 0x0, 0x3,1 },
    { 0x2209c8, 0x0, 0xf,1 },
    { 0x2209cc, 0x0, 0x0,1 },
    { 0x2209d0, 0x0, 0x0,1 },
    { 0x2209d4, 0x0, 0x0,1 },
    { 0x2209e0, 0x0, 0x0,4 },
    { 0x220a00, 0x6, 0x19fdf0f,4 },
    { 0x220a04, 0x1000700, 0xf0f1f03,4 },
    { 0x220a08, 0xffff, 0x0,2 },
    { 0x220a0c, 0x0, 0x0,2 },
    { 0x220a10, 0x780, 0x0,2 },
    { 0x220a14, 0x0, 0x0,2 },
    { 0x220a18, 0x0, 0x0,2 },
    { 0x220a1c, 0xffff, 0x0,2 },
    { 0x220a20, 0x0, 0x0,2 },
    { 0x220a24, 0x438, 0x0,2 },
    { 0x220a30, 0x1, 0x87,1 },
    { 0x220a34, 0x0, 0x30000,4 },
    { 0x220a80, 0x0, 0x1,1 },
    { 0x220a84, 0x0, 0x1,1 },
    { 0x220b00, 0x0, 0x7,1 },
    { 0x220b04, 0x4, 0x0,1 },
    { 0x220b08, 0xffff, 0x0,2 },
    { 0x220b0c, 0xffff, 0x0,2 },
    { 0x220b10, 0xffff, 0x0,2 },
    { 0x220b14, 0x8fff, 0x0,2 },
    { 0x220b18, 0x8fff, 0x0,2 },
    { 0x220b1c, 0x8fff, 0x0,2 },
    { 0x220b20, 0x3caa, 0x0,2 },
    { 0x220b24, 0x0, 0x0,2 },
    { 0x220b28, 0x1, 0x3fff,2 },
    { 0x220b2c, 0x100, 0x3fff,2 },
    { 0x220b30, 0x1, 0x3fff,2 },
    { 0x220b38, 0x100, 0x3fff,2 },
    { 0x220b80, 0x6, 0xcf,1 },
    { 0x220b84, 0x0, 0xf,1 },
    { 0x220b88, 0x780, 0x0,2 },
    { 0x220b8c, 0x438, 0x0,2 },
    { 0x220b90, 0x0, 0x0,4 },
    { 0x220b94, 0x0, 0x0,4 },
    { 0x220b98, 0x0, 0x0,4 },
    { 0x220b9c, 0x0, 0x0,4 },
    { 0x220ba0, 0x0, 0x0,4 },
    { 0x220ba4, 0x0, 0xf,1 },
    { 0x220ba8, 0xf00, 0x0,4 },
    { 0x220bac, 0x0, 0x3,1 },
    { 0x220bc8, 0x0, 0xf,1 },
    { 0x220bcc, 0x0, 0x0,1 },
    { 0x220bd0, 0x0, 0x0,1 },
    { 0x220bd4, 0x0, 0x0,1 },
    { 0x220be0, 0x0, 0x0,4 },
    { 0x220c00, 0x100006, 0x19fdf0f,4 },
    { 0x220c04, 0x0, 0xf0f1f03,4 },
    { 0x220c08, 0xffff, 0x0,2 },
    { 0x220c0c, 0x0, 0x0,2 },
    { 0x220c10, 0x0, 0x0,2 },
    { 0x220c14, 0x0, 0x0,2 },
    { 0x220c18, 0x0, 0x0,2 },
    { 0x220c1c, 0xffff, 0x0,2 },
    { 0x220c20, 0x0, 0x0,2 },
    { 0x220c24, 0x0, 0x0,2 },
    { 0x220c30, 0x0, 0x87,1 },
    { 0x220c34, 0x0, 0x30000,4 },
    { 0x220c80, 0x0, 0x1,1 },
    { 0x220c84, 0x0, 0x1,1 },
    { 0x220d00, 0x0, 0x7,1 },
    { 0x220d04, 0x3, 0x0,1 },
    { 0x220d08, 0xffff, 0x0,2 },
    { 0x220d0c, 0xffff, 0x0,2 },
    { 0x220d10, 0xffff, 0x0,2 },
    { 0x220d14, 0x8fff, 0x0,2 },
    { 0x220d18, 0x8fff, 0x0,2 },
    { 0x220d1c, 0x8fff, 0x0,2 },
    { 0x220d20, 0x3caa, 0x0,2 },
    { 0x220d24, 0x0, 0x0,2 },
    { 0x220d28, 0x1, 0x3fff,2 },
    { 0x220d2c, 0x100, 0x3fff,2 },
    { 0x220d30, 0x1, 0x3fff,2 },
    { 0x220d38, 0x100, 0x3fff,2 },
    { 0x220d80, 0x0, 0xcf,1 },
    { 0x220d84, 0x0, 0xf,1 },
    { 0x220d88, 0x780, 0x0,2 },
    { 0x220d8c, 0x438, 0x0,2 },
    { 0x220d90, 0x0, 0x0,4 },
    { 0x220d94, 0x0, 0x0,4 },
    { 0x220d98, 0x0, 0x0,4 },
    { 0x220d9c, 0x0, 0x0,4 },
    { 0x220da0, 0x0, 0x0,4 },
    { 0x220da4, 0x0, 0xf,1 },
    { 0x220da8, 0x4000, 0x0,4 },
    { 0x220dac, 0x0, 0x3,1 },
    { 0x220dc8, 0x0, 0xf,1 },
    { 0x220dcc, 0x0, 0x0,1 },
    { 0x220dd0, 0x0, 0x0,1 },
    { 0x220dd4, 0x0, 0x0,1 },
    { 0x220de0, 0x0, 0x0,4 },
    { 0x220e00, 0x0, 0x1,1 },
    { 0x220e10, 0x0, 0x1fff1fff,4 },
    { 0x220e14, 0x4650898, 0x1fff1fff,4 },
    { 0x220e18, 0x4380780, 0x1fff1fff,4 },
    { 0x220e1c, 0x30057, 0x1fff1fff,4 },
    { 0x220e20, 0x5002c, 0x1fff1fff,4 },
    { 0x220e24, 0xc, 0xc,1 },
    { 0x220f00, 0x0, 0x1010101,4 },
    { 0x220f10, 0x12a, 0x0,2 },
    { 0x220f14, 0x0, 0x0,2 },
    { 0x220f18, 0x199, 0x0,2 },
    { 0x220f1c, 0x12a, 0x0,2 },
    { 0x220f20, 0xf064, 0x0,2 },
    { 0x220f24, 0xf0d0, 0x0,2 },
    { 0x220f28, 0x12a, 0x0,2 },
    { 0x220f2c, 0x205, 0x0,2 },
    { 0x220f30, 0x0, 0x0,2 },
    { 0x220f38, 0x485, 0x1ffff,4 },
    { 0x220f40, 0x21e, 0x1ffff,4 },
    { 0x220f48, 0x400, 0x1ffff,4 },
    { 0x220f50, 0x0, 0x10301,4 },
    { 0x220f60, 0xffff, 0x0,2 },
    { 0x220f64, 0x0, 0x0,2 },
    { 0x220f68, 0xffff, 0x0,2 },
    { 0x220f6c, 0x0, 0x0,2 },
    { 0x220f70, 0xffff, 0x0,2 },
    { 0x220f74, 0xffff, 0x0,2 },
    { 0x220f78, 0xffff, 0x0,2 },
    { 0x220f7c, 0x0, 0x1000000,4 },
    { 0x220f80, 0x0, 0x1001f,4 },
    //stop sequence - address is 0x0000
    { 0x0000, 0x0000, 0x0000, 0x0000 }
};


static acam_reg_t linear[] = {
    { 0x18ed4, 0x30300, 0x30303,4 },
    { 0x18e8c, 0x0, 0x3000000,4 },
    { 0x18eac, 0x30, 0x30,1 },
    { 0x18f98, 0x20000, 0x70007,4 },
    //stop sequence - address is 0x0000
    { 0x0000, 0x0000, 0x0000, 0x0000 }
};


static acam_reg_t native[] = {
    { 0x18ed4, 0x30300, 0x30303,4 },
    { 0x18e8c, 0x2000000, 0x3000000,4 },
    { 0x18eac, 0x30, 0x30,1 },
    { 0x18f98, 0x20000, 0x70007,4 },
    //stop sequence - address is 0x0000
    { 0x0000, 0x0000, 0x0000, 0x0000 }
};


static acam_reg_t fpga_linear[] = {
    { 0x220500, 0x1, 0x70f03,4 },
    { 0x220504, 0x0, 0x70f03,4 },
    { 0x220508, 0x0, 0x70f03,4 },
    { 0x22050c, 0x0, 0x70f03,4 },
    { 0x220550, 0x0, 0x1,1 },
    { 0x220590, 0x0, 0x1,1 },
    { 0x2205d0, 0x0, 0x1,1 },
    { 0x220520, 0x3030303, 0x7070707,4 },
    { 0x220524, 0x0, 0x7,1 },
    //stop sequence - address is 0x0000
    { 0x0000, 0x0000, 0x0000, 0x0000 }
};

static const acam_reg_t *seq_table[] = {
    settings,
    settings_context,
    settings_fpga,
    linear,
    native,
    fpga_linear
};

#define SENSOR_ISP_SEQUENCE_DEFAULT seq_table

#define SENSOR_ISP_SEQUENCE_DEFAULT_SETTINGS    0
#define SENSOR_ISP_SEQUENCE_DEFAULT_SETTINGS_CONTEXT    1
#define SENSOR_ISP_SEQUENCE_DEFAULT_SETTINGS_FPGA    2
#define SENSOR_ISP_SEQUENCE_DEFAULT_LINEAR    3
#define SENSOR_ISP_SEQUENCE_DEFAULT_NATIVE    4
#define SENSOR_ISP_SEQUENCE_DEFAULT_FPGA_LINEAR    5
#endif /* __ISP_SENSOR_H__ */
